@@ -34,6 +34,37 @@ email                : markey@web.de
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include <tqcombobox.h>
+#include <tqgroupbox.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
+#include <tqmessagebox.h>
+#include <tqobjectlist.h>
+#include <tqpushbutton.h>
+#include <tqradiobutton.h>
+#include <tqspinbox.h>
+#include <tqtextcodec.h>
+#include <tqtooltip.h>
+#include <tqvbox.h>
+#include <tqlistview.h>
+#include <tqcheckbox.h>
+
+#include <tdeapplication.h> //kapp
+#include <kcombobox.h>
+#include <kiconloader.h>
+#include <klineedit.h>
+#include <tdelocale.h>
+#include <kstandarddirs.h>
+#include <kdebug.h>
+#include <dcopref.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
+
 #include "configdialog.h"
 #include "konqueror.h"
 #include "firewallsproxies.h"
@@ -49,34 +80,7 @@ email                : markey@web.de
 #include "portsandnames.h"
 #include "tork.h"
 #include "crypto.h"
-#include "../config.h"
 
-#include <ntqcombobox.h>
-#include <ntqgroupbox.h>
-#include <ntqlabel.h>
-#include <ntqlayout.h>
-#include <ntqlineedit.h>
-#include <ntqmessagebox.h>
-#include <ntqobjectlist.h>
-#include <ntqpushbutton.h>
-#include <ntqradiobutton.h>
-#include <ntqspinbox.h>
-#include <ntqtextcodec.h>
-#include <ntqtooltip.h>
-#include <ntqvbox.h>
-#include <ntqlistview.h>
-#include <ntqcheckbox.h>
-
-#include <tdeapplication.h> //kapp
-#include <kcombobox.h>
-#include <kiconloader.h>
-#include <klineedit.h>
-#include <tdelocale.h>
-#include <kstandarddirs.h>
-#include <kdebug.h>
-#include <dcopref.h>
-#include <tdeconfig.h>
-#include <tdemessagebox.h>
 
 //////////////////////////////////////////////////////////////////////////////////////////
 // PUBLIC
