@@ -18,6 +18,19 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.         *
  ***************************************************************************/
 
+#include <tqvalidator.h>
+#include <tqaction.h>
+#include <tqlayout.h>
+#include <tqtoolbutton.h>
+#include <tqcheckbox.h>
+#include <tqradiobutton.h>
+#include <tqbuttongroup.h>
+#include <tqvgroupbox.h>
+#include <tqpopupmenu.h>
+#include <tqtextedit.h>
+#include <tqlabel.h>
+#include <tqhttp.h>
+
 #include <tdeapplication.h>
 #include <tdeaboutdata.h>
 #include <tdeconfig.h>
@@ -27,28 +40,14 @@
 #include <tdelocale.h>
 #include <kdebug.h>
 #include <tdemessagebox.h>
-#include <ntqlayout.h>
-#include <ntqtoolbutton.h>
 #include <kpushbutton.h>
-#include <ntqcheckbox.h>
-#include <ntqradiobutton.h>
-#include <ntqbuttongroup.h>
-#include <ntqvgroupbox.h>
 #include <kguiitem.h>
-#include <ntqpopupmenu.h>
-#include <ntqtextedit.h>
-#include <ntqlayout.h>
-#include <ntqlabel.h>
 #include <kdialogbase.h>
-#include <ntqhttp.h>
 #include <kurl.h>
 #include <kinputdialog.h>
-#include <ntqvalidator.h>
-#include <ntqaction.h>
 #include <kdebug.h>
 
 #include <pwd.h>
-
 #include <iostream>
 #include <unistd.h>
 
@@ -137,9 +136,9 @@ void LikeBackBar::autoMove()
 
 		if (window != lastWindow && m_likeBack->windowNamesListing() != LikeBack::NoListing) {
 			if (tqstricmp(window->name(), "") == 0 || tqstricmp(window->name(), "unnamed") == 0) {
-				std::cout << "===== LikeBack ===== UNNAMED ACTIVE WINDOW OF TYPE " << window->className() << " ======" << LikeBack::activeWindowPath() << std::endl;
+				std::cout << "===== LikeBack ===== UNNAMED ACTIVE WINDOW OF TYPE " << window->className() << " ======" << LikeBack::activeWindowPath().local8Bit() << std::endl;
 			} else if (m_likeBack->windowNamesListing() == LikeBack::AllWindows) {
-				std::cout << "LikeBack: Active Window: " << LikeBack::activeWindowPath() << std::endl;
+				std::cout << "LikeBack: Active Window: " << LikeBack::activeWindowPath().local8Bit() << std::endl;
 			}
 		}
 		lastWindow = window;
@@ -818,8 +817,8 @@ void LikeBackDialog::send()
 		"email="    + KURL::encode_string(emailAddress);
 	TQHttp *http = new TQHttp(m_likeBack->hostName(), m_likeBack->hostPort());
 
-	std::cout << "http://" << m_likeBack->hostName() << ":" << m_likeBack->hostPort() << m_likeBack->remotePath() << std::endl;
-	std::cout << data << std::endl;
+	std::cout << "http://" << m_likeBack->hostName().local8Bit() << ":" << m_likeBack->hostPort() << m_likeBack->remotePath().local8Bit() << std::endl;
+	std::cout << data.local8Bit() << std::endl;
 	connect( http, SIGNAL(requestFinished(int, bool)), this, SLOT(requestFinished(int, bool)) );
 
 	TQHttpRequestHeader header("POST", m_likeBack->remotePath());
