@@ -41,7 +41,7 @@
 
 class TestPrivoxy : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     TestPrivoxy( );
 
