@@ -63,7 +63,7 @@ class PrevConfig
 
 class TorClient : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     TorClient( const TQString &host, TQ_UINT16 port );
 
