@@ -19,14 +19,15 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
-#include <ntqtooltip.h>
-#include <ntqpopupmenu.h>
-#include <kdebug.h>
-#include <ntqclipboard.h>
+#include <tqtooltip.h>
+#include <tqpopupmenu.h>
+#include <tqclipboard.h>
 
+#include <kdebug.h>
 #include <tdeapplication.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
+
 #include "torkconfig.h"
 #include "tork.h"
 #include "crypto.h"
