@@ -19,21 +19,18 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
-#include "update.h"
+#include <tqtimer.h>
+#include <tqdir.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
 
 #include <kstaticdeleter.h>
-
 #include <tdelocale.h>
 #include <tdeio/netaccess.h>
-
-
 #include <tdeaction.h>
-
-#include <ntqcheckbox.h>
 #include <kbuttonbox.h>
 #include <kurlcompletion.h>
 #include <kcombobox.h>
-#include <ntqlayout.h>
 #include <tdemessagebox.h>
 #include <klineedit.h>
 #include <tdetempfile.h>
@@ -47,12 +44,12 @@
 #include <dcopclient.h>
 #include <kuser.h>
 
-#include <ntqtimer.h>
-#include <ntqdir.h>
-#include "version.h"
-
 #include <stdlib.h>
 
+#include "version.h"
+#include "update.h"
+
+
 const char *mirrors[] = {
     "heanet",
     "internap",
@@ -245,10 +242,10 @@ void TorkUpdate::downloadComponent(TQString component, TQString version, TQStrin
 
     if (torkdir.exists() && configurefile.exists()){
 
-        chmod((const char *)configure,0700);
+        chmod(configure.local8Bit(), 0700);
 
         int result = KMessageBox::warningContinueCancel(0, i18n( "%1-%2 is ready for compiling and installation. Would you like the wizard to ask you for the root password so it can compile and install it for you? (If not, you can compile it yourself later at %3/%4-%5)").arg(component).arg(version).arg(location).arg(component).arg(version),i18n( "Install %1-%2" ).arg(component).arg(version),i18n( "Use the Wizard" ));
-        
+
         switch (result) {
             case 2 : 
                 KMessageBox::information (0,i18n("Installation of %1 Cancelled.").arg(component));
